<?php
$lang['friendlyname'] = 'Livres d\'or';
$lang['moddescription'] = 'Créer et gérer des livres d\'or pour obtenir les avis des internautes.';
$lang['description'] = 'Obtenir des avis de vos visiteurs';
$lang['postinstall'] = 'The Gbook module was successfully installed. Check the admin Content section for \'%s\'.';
$lang['spam'] = 'Pourriel';
$lang['areyousure'] = 'Êtes-vous sûr de vouloir supprimer ?';
$lang['areyousuremulti'] = 'Êtes-vous sûr de vouloir exécuter cette action groupée ?';
$lang['gbooks'] = 'Livres d\'or';
$lang['addgbook'] = 'Ajouter un livre d\'or';
$lang['gbookadded'] = 'Livre d\'or ajouté';
$lang['editgbook'] = 'Modifier le livre d\'or';
$lang['gbookupdated'] = 'Livre d\'or modifié';
$lang['gbookdeleted'] = 'Le livre d\'or est supprimé';
$lang['entries_page'] = 'Nombre de message par page';
$lang['prevent_post_twice'] = 'Empêcher des messages consécutifs par le même utilisateur (basé sur l\'adresse IP)';
$lang['allow_smilies'] = 'Autorise les smileys';
$lang['allow_notifications'] = 'Activer l\'option de notification';
$lang['notification_subject'] = 'Sujet du mail de notification';
$lang['notification_message'] = 'Message du mail de notification';
$lang['submission_response'] = 'Reponse à la soumission du message.';
$lang['submission_response_spam'] = 'Réponse à la soumission d\'un message suspecté de spam';
$lang['admin_notification_subject'] = 'Sujet du mail de notification de l\'admin';
$lang['admin_notification_message'] = 'Message du mail de notification de l\'admin';
$lang['required_fields'] = 'Champs obligatoires dans le formulaire en ligne';
$lang['import_csv'] = 'Importer des messages au format csv';
$lang['csv_format'] = 'csv format: "author"[string];"email"[string];"title"[string];"message"[string];"ip"[string];"create_date"[date/time:yyyy-mm-dd hh:mm:ss]';
$lang['smileys'] = 'Smileys';
$lang['smiley'] = 'Smiley';
$lang['addsmiley'] = 'Ajouter Smiley';
$lang['id'] = 'ID';
$lang['spamrate'] = 'Niveau de spam';
$lang['created'] = 'Créé';
$lang['modified'] = 'Modifié';
$lang['approved'] = 'Approuvé';
$lang['itemadded'] = 'Le message est ajouté';
$lang['edititem'] = 'Modifier le message';
$lang['itemupdated'] = 'Message  est modifiée';
$lang['itemdeleted'] = 'Message est supprimér';
$lang['saveasham'] = 'Marqué le message comme  "Ham"';
$lang['saveasspam'] = 'Marqué le message comme "Spam"';
$lang['deletefromham'] = 'Ne pas marquer comme "Ham"';
$lang['deletefromspam'] = 'Ne pas marquer comme "Spam"';
$lang['summary_tpl'] = 'vue sommaire';
$lang['detail_tpl'] = 'vue détail';
$lang['form_tpl'] = 'formulaire de soumission en ligne';
$lang['default_summary_template'] = 'Gabarit de sommaire par défaut';
$lang['default_detail_template'] = 'Gabarit de détail par défaut';
$lang['resetdefault'] = 'Charger/réinitialiser le gabarit par défaut';
$lang['resetwarning'] = 'Êtes-vous sûr de vouloir réinitialiser le code de ce gabarit ?';
$lang['title_custom_modulename'] = 'Nom de module personnalisé';
$lang['send_notifications_to'] = 'Send notification of new entries to editor';
$lang['max_spamrate_active'] = 'Maximum spamrating to automatically set an entry active on submit';
$lang['max_spamrate_active_help'] = 'between 0 and 1, default 0.6. Lower value means tighter setting.';
$lang['max_spamrate_notify'] = 'Maximum spamrating for sending a notification to editor';
$lang['max_spamrate_notify_help'] = 'between 0 and 1, default 0.9. Higher value will increase the chance of getting notifications of spam entries.';
$lang['max_spamrate_save'] = 'Maximum spamrating for saving a new entry';
$lang['max_spamrate_save_help'] = 'between 0 and 1, default 0.9. Lower value will increase the chance of losing legitimate entries.';
$lang['badwords'] = 'Filter bad words (comma separated)';
$lang['optionsupdated'] = 'The options were successfully updated.';
$lang['entries'] = 'Messages';
$lang['name'] = 'Nom';
$lang['email'] = 'E-mail';
$lang['title'] = 'Titre';
$lang['message'] = 'Message';
$lang['notify'] = 'M\'informer des nouveaux messages';
$lang['fe_submit'] = 'Envoyer';
$lang['validation_errors'] = 'Merci de saisir des données valides pour les champs indiqués et de re-valider.';
$lang['double_post'] = '<p>Merci pour votre message. Celui-ci a été ajouté au livre d\'or.</p>';
$lang['not_allowed_to_post_twice'] = '<p>Désolé, pour des raisons de sécurité, il n\'est pas possible de soumettre deux messages consécutifs par la même personne.</p>
<p>Merci d\'essayer plus tard ou bien envoyez-nous un email afin que nous ajoutions nous-même votre message.</p>';
$lang['submission_response_cnt'] = '<p>Merci pour votre message. Celui-ci a été ajouté au livre d\'or.</p>';
$lang['submission_response_spam_cnt'] = '<p>Merci pour votre message.</p>

<p>Celui étant cependant suspecté de contenir du contenu indésirable, il doit être validé par un administrateur avant d\'être affiché.</p>
<p>Merci de nous en informer en nous envoyant un e-mail.</p>';
$lang['admin_notification_subject_cnt'] = 'Nouveau message sur le livre d\'or';
$lang['admin_notification_message_cnt'] = 'Vous avez reçu un nouveau message sur le livre d\'or sur site {sitename}.

Pour le consulter, rendez-vous sur {root_url}';
$lang['help_action'] = 'Possible values: <ul><li>\'default\' - for displaying the guestbook entries</li><li>\'form\' - for displaying a form</li><li>\'detail\' - for displaying a single entry, e.g. as search result</li></ul>';
$lang['help_alias'] = 'Use another guestbook than the default one. Check the Guestbooks-tab, column \'Tags\', to see which aliases can be used.';
$lang['help_entryid'] = 'Use this parameter along with <code>action=\'detail\'</code> if you want to display only one guestbook entry. To get the latest entry, use <code>entryid=-1</code>';
$lang['help_template'] = 'Use another template than the default one. Note that templates must be of the proper type, in accordance with the action parameter.';
$lang['help'] = '<h3>What Does This Do?</h3>
<p>The Gbook module provides your site visitors a convenient way to give some feedback on your site. Messages can include smileys and your guestbook is effectively protected from spam without the necessity of using an annoying captcha.</p>
<h3>How Do I Use It</h3>
<p>To show the guestbook entries, just insert the module with the<code> {Gbook} </code>tag into the content section of a page.<br />
You can display a form with the<code> {Gbook action=\'form\'} </code>tag.</p>
<p>To get a quick start, a sample stylesheet has been installed which corresponds with the default module templates. Attach the stylesheet \'Gbook module\' to your page template(s) to give your guestbook a first good look.</p>

<h3>Edit Guestbook Entries</h3>
<p>Users with the \'Gbook: Use\' permission can edit guestbook entries in the backend.</p>

<h3>Spam Protection</h3>
<p>Gbook proudly uses the "b8" statistical (Bayesian) spam filter version 0.6, written by Tobias Leupold. This built-in spam protection system will only function after you have learned it how to interpret the messages by marking the first few entries as either "Spam" or "Ham". If the system has learned enough good as well as enough bad words, it will give spam messages a rating somewhere near 1, and ham messages will be rated somewhere near 0. Messages with a rating of 0.50 could not be rated because of too few matching words.<br />Note that it won\'t be of use to manually mark entries as spam or ham, which are already rated as such.</p>
<p>If you want to know more of this excellent spam protection system, you can visit <a href="http://nasauber.de/opensource/b8/">nasauber.de</a>.</p>

<h3>Customisation</h3>
<p>The Guestbooks-tab in the admin section allows you to create more separate guestbooks. Each can have its own settings.<br />
Users must belong to a group with the \'Gbook: Modify\' permission to be able to create new guestbooks and to change settings.</p>

<h3>Import Guestbook Entries</h3>
<p>If you are migrating your site from another CMS or from another guestbook system, you probably might want to create a csv file containing all entries you have received in the past.</p>
<p>This csv file can easily be imported to Gbook, when it is formatted with fields in a specific order, separated by semicolons and enclosed by double quotes, like this:<br />
<code>"author";"email";"title";"message";"ip";"create_date"</code></p>
<p>All fields are of type [string]. The field <em>create_date</em> needs to be formatted as "yyyy-mm-dd hh:mm:ss"</p>

<h3>Edit Gbook templates</h3>
<p>In order to edit templates, the user must belong to a group with the \'Modify Templates\' permission.</p>

<h3>Global Gbook Options</h3>
<p>To edit the global Gbook options, the user must belong to a group with the \'Modify Site Preferences\' permission.</p>

<h3>Support</h3>
<p>This module does not include commercial support. However, there are a number of resources available to help you with it:</p>
<ul>
<li>For the latest version of this module or to file a Feature Request or Bug Report, please visit the Module Forge
<a href="http://dev.cmsmadesimple.org/projects/gbook/">Gbook Page</a>.</li>
<li>Additional discussion of this module may also be found in the <a href="https://forum.cmsmadesimple.org">CMS Made Simple Forums</a>. You are warmly invited to open a new topic if you didn\'t find an answer to your question.</li>
<li>Lastly, you may have some success emailing the author directly.</li>
</ul>

<h3>Feedback</h3>
<p>If you enjoy this module, use it on a commercial website or would like to encourage future development, you might consider just a small donation.<br />Or leave a message in the <a href="https://forum.cmsmadesimple.org/viewtopic.php?f=7&t=64460">Gbook forum topic</a>. Any kind of feedback will be much appreciated.</p>';
?>